=======
Credits
=======

Development Lead
----------------

* Michael Goerz <mail@michaelgoerz.net>

Development Team
----------------

* Daniel Reich <daniel.reich@physik.uni-kassel.de>
* Daniel Basilewitsch <basilewitsch@physik.uni-kassel.de>
* Karl Horn <karlhorn@physik.uni-kassel.de>
* Fernando Gago Encinas <fernando.gago@physik.uni-kassel.de>
* Matthias Krauss <matthias.krauss@physik.uni-kassel.de>
* Christiane Koch <christiane.koch@uni-kassel.de>
